#ifndef NT2_INCLUDE_FUNCTIONS_IS_UNORD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_UNORD_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_unord.hpp>

#endif
